@@ -2,7 +2,6 @@ import React from 'react';
 import PropTypes from 'prop-types';
 import { gettext } from '../../../../utils/constants';
 import Icon from '../../../icon';
-import Title from './title';
 
 import './index.css';
 
@@ -10,15 +9,22 @@ const Header = ({ title, icon, iconSize = 32, onClose, children, component = {}
   const { closeIcon } = component;
   return (
     <div className="detail-header">
-      <Title title={title} icon={icon} iconSize={iconSize} />
+      <div className="detail-title dirent-title">
+        {icon && (
+          <div className="detail-header-icon-container">
+            <img src={icon} width={iconSize} height={iconSize} alt="" />
+          </div>
+        )}
+        <span className="detail-title-name ellipsis" title={title}>{title}</span>
+      </div>
       {(children || onClose) && (
         <div className="detail-control-container">
           {children}
-          {onClose && (
+          {onClose &&
             <div className="detail-control" onClick={onClose} title={gettext('Close')}>
               {closeIcon ? closeIcon : <Icon symbol="close" className="detail-control-icon" />}
             </div>
-          )}
+          }
         </div>
       )}
     </div>
