@@ -2,6 +2,7 @@ import React, { useMemo } from 'react';
 import PropTypes from 'prop-types';
 import classnames from 'classnames';
 import { getDateDisplayString } from '../../../utils/cell/column/date';
+import { formatWithTimezone } from '../../../../utils/time';
 
 import './index.css';
 
@@ -14,7 +15,7 @@ const DateFormatter = ({ value, format, className, children: emptyFormatter }) =
   return (
     <div
       className={classnames('sf-metadata-ui cell-formatter-container date-formatter', className)}
-      title={displayValue}
+      title={formatWithTimezone(value)}
     >
       {displayValue}
     </div>
