@@ -18,12 +18,3 @@ export const GALLERY_DATE_MODE = {
 export const STORAGE_GALLERY_DATE_MODE_KEY = 'gallery_date_mode';
 
 export const STORAGE_GALLERY_ZOOM_GEAR_KEY = 'gallery_zoom_gear';
-
-export const GALLERY_OPERATION_KEYS = {
-  DOWNLOAD: 'download',
-  DELETE: 'delete',
-  COPY: 'copy',
-  REMOVE_PHOTO_FROM_CURRENT_SET: 'remove_photo_from_current_set',
-  SET_PHOTO_AS_COVER: 'set_photo_as_cover',
-  ADD_PHOTO_TO_GROUPS: 'add_photo_to_groups'
-};
