@@ -31,7 +31,7 @@ import DirTool from '../../components/cur-dir-path/dir-tool';
 import Detail from '../../components/dirent-detail';
 import DirColumnView from '../../components/dir-view-mode/dir-column-view';
 import SelectedDirentsToolbar from '../../components/toolbar/selected-dirents-toolbar';
-import MetadataPathToolbar from '../../components/toolbar/metadata-path-toolbar';
+import ViewToolbar from '../../components/toolbar/view-toolbar';
 import { eventBus } from '../../components/common/event-bus';
 import WebSocketClient from '../../utils/websocket-service';
 
@@ -107,7 +107,6 @@ class LibContentView extends React.Component {
       tagId: '',
       currentDirent: null,
     };
-
     this.oldOnpopstate = window.onpopstate;
     window.onpopstate = this.onpopstate;
     this.lastModifyTime = new Date();
@@ -239,6 +238,7 @@ class LibContentView extends React.Component {
     try {
       const repoInfo = await this.fetchRepoInfo(repoID);
       const isGroupOwnedRepo = repoInfo.owner_email.includes('@seafile_group');
+      document.title = repoInfo.repo_name;
 
       this.setState({
         treeData: treeHelper.buildTree(),
@@ -303,16 +303,7 @@ class LibContentView extends React.Component {
   handleError = (error) => {
     let errorMsg = gettext('Please check the network.');
     if (error.response) {
-      switch (error.response.status) {
-        case 403:
-          errorMsg = gettext('Permission denied');
-          break;
-        case 404:
-          errorMsg = gettext('Library share permission not found.');
-          break;
-        default:
-          errorMsg = gettext('Error');
-      }
+      errorMsg = error.response.data.error_msg || gettext('Error');
     }
     this.setState({
       isDirentListLoading: false,
@@ -336,6 +327,7 @@ class LibContentView extends React.Component {
       currentRepoInfo: null,
     });
     this.socket.close();
+    this.props.resetTitle();
   }
 
   componentDidUpdate(prevProps) {
@@ -492,7 +484,6 @@ class LibContentView extends React.Component {
 
   showDir = (path) => {
     let repoID = this.props.repoID;
-    this.props.resetTitle();
 
     if (!this.state.isSessionExpired) {
       // update state
@@ -2451,9 +2442,26 @@ class LibContentView extends React.Component {
         onCopyItem={this.onCopyItem}
       >
         <DndProvider backend={HTML5Backend}>
-          <MetadataStatusProvider repoID={repoID} repoInfo={currentRepoInfo} currentPath={path} hideMetadataView={this.hideMetadataView} statusCallback={this.metadataStatusCallback} >
-            <MetadataMiddlewareProvider repoID={repoID} currentPath={path} repoInfo={currentRepoInfo} selectTagsView={this.onTreeNodeClick} tagsChangedCallback={this.tagsChangedCallback}>
-              <MetadataProvider repoID={repoID} currentPath={path} repoInfo={currentRepoInfo} selectMetadataView={this.onTreeNodeClick} >
+          <MetadataStatusProvider
+            repoID={repoID}
+            repoInfo={currentRepoInfo}
+            currentPath={path}
+            hideMetadataView={this.hideMetadataView}
+            statusCallback={this.metadataStatusCallback}
+          >
+            <MetadataMiddlewareProvider
+              repoID={repoID}
+              currentPath={path}
+              repoInfo={currentRepoInfo}
+              selectTagsView={this.onTreeNodeClick}
+              tagsChangedCallback={this.tagsChangedCallback}
+            >
+              <MetadataProvider
+                repoID={repoID}
+                currentPath={path}
+                repoInfo={currentRepoInfo}
+                selectMetadataView={this.onTreeNodeClick}
+              >
                 <div className="main-panel-center flex-row">
                   <div className="cur-view-container">
                     {this.state.currentRepoInfo.status === 'read-only' &&
@@ -2469,12 +2477,13 @@ class LibContentView extends React.Component {
                         })}>
                         {isDirentSelected ? (
                           currentMode === TAGS_MODE || currentMode === METADATA_MODE ? (
-                            <MetadataPathToolbar
+                            <ViewToolbar
                               repoID={repoID}
                               repoInfo={currentRepoInfo}
                               mode={currentMode}
                               path={path}
                               viewId={viewId}
+                              updateCurrentDirent={this.updateCurrentDirent}
                             />
                           ) : (
                             <SelectedDirentsToolbar
