@@ -111,7 +111,6 @@
     "Are you sure you want to clean invalid upload links?": "Ali ste prepri\u010dani, da \u017eelite izbrisati neveljavne povezave za prenos?",
     "Are you sure you want to clear trash?": "Ali ste prepri\u010dani, da \u017eelite sprazniti smeti?",
     "Are you sure you want to delete": "Ali ste prepri\u010dani, da \u017eelite izbrisati?",
-    "Are you sure you want to delete %s ?": "Ali si prepri\u010dan/a, da \u017eeli\u0161 odstraniti %s ?",
     "Are you sure you want to delete WebDAV password?": "Ali ste prepri\u010dani, da \u017eelite izbrisati geslo za WebDAV?",
     "Are you sure you want to delete Wiki": "Ali ste prepri\u010dani, da \u017eelite izbrisati Wiki?",
     "Are you sure you want to delete the notification ?": "Ali ste prepri\u010dani, da \u017eelite izbrisati obvestilo?",
@@ -315,7 +314,6 @@
     "Dimensions": "Dimensions",
     "Direct download link": "Direct download link",
     "Direct download link is copied to the clipboard.": "Direct download link is copied to the clipboard.",
-    "Disable SAML user email / password login": "Disable SAML user email / password login",
     "Disconnect": "Disconnect",
     "Discussion": "Razprave",
     "Display files": "Display files",
@@ -474,7 +472,6 @@
     "Folder does not exist.": "Folder does not exist.",
     "Folders": "Mape",
     "Force user to change password when account is newly added or reset by admin": "Force user to change password when account is newly added or reset by admin",
-    "Force user to use SSO login if SAML account is bound": "Force user to use SSO login if SAML account is bound",
     "Force user to use a strong password when sign up or change password.": "Force user to use a strong password when sign up or change password.",
     "Format": "Format",
     "Freeze Document": "Freeze Document",
@@ -805,7 +802,6 @@
     "Pictures and videos": "Pictures and videos",
     "Platform": "Os",
     "Please check the network.": "Prosimo, preverite povezavo.",
-    "Please choose a .sdoczip file.": "Please choose a .sdoczip file.",
     "Please choose a .xlsx file.": "Please choose a .xlsx file.",
     "Please choose an image file.": "Please choose an image file.",
     "Please enter 1 or more character": "Prosimo, vpi\u0161i 1 ali ve\u010d znakov",
@@ -920,6 +916,7 @@
     "Search property": "Search property",
     "Search users": "Search users",
     "Search users...": "Iskanje uporabnikov...",
+    "Searching...": "Iskanje...",
     "Select File": "Select File",
     "Select a department": "Izberi oddelek",
     "Select a user": "Select a user",
