@@ -24,10 +24,11 @@ from seaserv import seafile_api, ccnet_api
 from seahub.api2.authentication import TokenAuthentication
 from seahub.api2.endpoints.utils import is_org_user
 from seahub.api2.throttling import UserRateThrottle
-from seahub.api2.utils import api_error, to_python_boolean, get_user_common_info
+from seahub.api2.utils import api_error, to_python_boolean, get_user_common_info, get_user_contact_email
 from seahub.api2.models import TokenV2
 from seahub.organizations.models import OrgSettings
 from seahub.organizations.views import gen_org_url_prefix
+from seahub.utils.auth import can_user_update_password
 from seahub.utils.ccnet_db import get_ccnet_db_name
 import seahub.settings as settings
 from seahub.settings import SEND_EMAIL_ON_ADDING_SYSTEM_MEMBER, INIT_PASSWD, \
@@ -1029,9 +1030,6 @@ class AdminSearchUser(APIView):
             # search user from ccnet db
             users += ccnet_api.search_emailusers('DB', query_str, 0, 10)
 
-            # search user from ccnet ldapimport
-            users += ccnet_api.search_emailusers('LDAP', query_str, 0, 10)
-
             ccnet_user_emails = [u.email for u in users]
 
             # get institution for user from ccnet
@@ -1083,30 +1081,14 @@ class AdminSearchUser(APIView):
 
             ccnet_users = []
             ccnet_db_users = ccnet_api.search_emailusers('DB', query_str, 0, page * per_page)
-            ccnet_ldap_import_users = []
 
             if len(ccnet_db_users) == page * per_page:
 
                 # users from ccnet db is enough
                 ccnet_users = ccnet_db_users[-per_page:]
 
-            elif len(ccnet_db_users) < page * per_page:
-
-                ccnet_ldap_import_users = ccnet_api.search_emailusers('LDAP',
-                                                                      query_str,
-                                                                      0,
-                                                                      page*per_page - len(ccnet_db_users))
-
-                if int(len(ccnet_db_users)/per_page) == page-1:
-                    # need ccnet_db_users + ccnet_ldap_import_users
-                    ccnet_users = ccnet_db_users[(page-1)*per_page-len(ccnet_db_users):] + ccnet_ldap_import_users
-
-                if int(len(ccnet_db_users)/per_page) < page-1:
-                    # users only from ccnet_ldap_import_users
-                    ccnet_users = ccnet_ldap_import_users[-per_page:]
-
             # search user from profile
-            all_ccnet_users = ccnet_db_users + ccnet_ldap_import_users
+            all_ccnet_users = ccnet_db_users
             all_profile_users = []
 
             if len(all_ccnet_users) == page * per_page:
@@ -1178,7 +1160,7 @@ class AdminSearchUser(APIView):
             info['avatar_url'] = url
             info['email'] = user.email
             info['name'] = email2nickname(user.email)
-            info['contact_email'] = email2contact_email(user.email)
+            info['contact_email'] = get_user_contact_email(user.email)
 
             info['is_staff'] = user.is_staff
             info['is_active'] = user.is_active
@@ -1500,23 +1482,16 @@ class AdminUserResetPassword(APIView):
             error_msg = 'email invalid'
             return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
 
-        has_bind_social_auth = False
-        if SocialAuthUser.objects.filter(username=email).exists():
-            has_bind_social_auth = True
-
-        can_reset_password = True
-        if has_bind_social_auth and (not ENABLE_SSO_USER_CHANGE_PASSWORD):
-            can_reset_password = False
-
-        if not can_reset_password:
-            return api_error(status.HTTP_400_BAD_REQUEST, _('Unable to reset password.'))
-
         try:
             user = User.objects.get(email=email)
         except User.DoesNotExist as e:
             logger.error(e)
             error_msg = 'email invalid.'
             return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+        
+        can_reset_password = can_user_update_password(user)
+        if not can_reset_password:
+            return api_error(status.HTTP_400_BAD_REQUEST, _('Unable to reset password.'))
 
         profile = Profile.objects.get_profile_by_user(email)
         if IS_EMAIL_CONFIGURED and profile and profile.contact_email:
