@@ -656,7 +656,7 @@ TERMS_OF_SERVICE_LINK = ''
 ALLOWED_HOSTS = ['*']
 
 # Logging
-seafile_log_to_stdout = os.getenv('SEAFILE_LOG_TO_STDOUT', 'false') == 'true'
+seafile_log_to_stdout = os.getenv('SEAFILE_LOG_TO_STDOUT', 'false').lower() == 'true'
 if seafile_log_to_stdout:
     LOGGING = {
         'version': 1,
@@ -870,7 +870,7 @@ SESSION_COOKIE_AGE = 24 * 60 * 60
 # Days of remembered login info (deafult: 7 days)
 LOGIN_REMEMBER_DAYS = 7
 
-SEAFILE_VERSION = '13.0.11'
+SEAFILE_VERSION = '13.0.12'
 
 CAPTCHA_IMAGE_SIZE = (90, 42)
 
@@ -980,7 +980,7 @@ ENABLE_WHITEBOARD = False
 # Settings for notification server   #
 ######################################
 
-ENABLE_NOTIFICATION_SERVER = os.environ.get('ENABLE_NOTIFICATION_SERVER', 'false') == 'true'
+ENABLE_NOTIFICATION_SERVER = os.environ.get('ENABLE_NOTIFICATION_SERVER', 'false').lower() == 'true'
 NOTIFICATION_SERVER_URL = os.environ.get('NOTIFICATION_SERVER_URL', '')
 INNER_NOTIFICATION_SERVER_URL = os.environ.get('INNER_NOTIFICATION_SERVER_URL', 'http://127.0.0.1:8083' )
 
@@ -1125,10 +1125,6 @@ def load_local_settings(module):
     that begin with "EXTRA_".
 
     '''
-    if hasattr(module, 'HTTP_SERVER_ROOT'):
-        if not hasattr(module, 'FILE_SERVER_ROOT'):
-            module.FILE_SERVER_ROOT = module.HTTP_SERVER_ROOT
-        del module.HTTP_SERVER_ROOT
     for attr in dir(module):
         match = re.search(r'^EXTRA_(\w+)', attr)
         if match:
@@ -1140,6 +1136,20 @@ def load_local_settings(module):
                 globals()[name] = value
         elif re.search('^[A-Z]', attr):
             globals()[attr] = getattr(module, attr)
+            
+def logger_error(error, filename='seahub_settings.py'):
+    from datetime import datetime
+    import traceback
+    
+    log_time = datetime.now().strftime('%Y-%m-%d %H:%M:%S')
+    error_type = type(error).__name__
+    error_traceback = traceback.format_exc()
+    log_entry = f"[{log_time}] [ERROR] {filename} load: {error_type}: {str(error)}\n{error_traceback}\n"
+    
+    log_file_path = os.path.join(LOG_DIR, 'seahub.log')
+    with open(log_file_path, 'a', encoding='utf-8') as f:
+        f.write(log_entry)
+
 
 # Load local_settings.py
 try:
@@ -1157,6 +1167,8 @@ try:
     import seahub_settings
 except ImportError:
     pass
+except Exception as e:
+    logger_error(e)
 else:
     # In server release, sqlite3 db file is <topdir>/seahub.db
     DATABASES['default']['NAME'] = os.path.join(install_topdir, 'seahub.db')
@@ -1269,8 +1281,8 @@ elif CACHE_PROVIDER == 'memcached':
 else:
     raise ValueError(f'Invalid CACHE_PROVIDER: {CACHE_PROVIDER}')
 
-if os.environ.get('ENABLE_SEADOC', ''):
-    ENABLE_SEADOC = os.environ.get('ENABLE_SEADOC', '').lower() == 'true'
+if os.environ.get('ENABLE_SEADOC'):
+    ENABLE_SEADOC = os.environ.get('ENABLE_SEADOC', 'false').lower() == 'true'
 SEADOC_PRIVATE_KEY = JWT_PRIVATE_KEY
 EXCALIDRAW_PRIVATE_KEY = JWT_PRIVATE_KEY
 SEADOC_SERVER_URL = os.environ.get('SEADOC_SERVER_URL', '') or SEADOC_SERVER_URL
@@ -1292,15 +1304,15 @@ sys.path.pop(0)
 # Following settings are private, can not be overwrite.
 INNER_FILE_SERVER_ROOT = 'http://127.0.0.1:' + FILE_SERVER_PORT
 
-if os.environ.get('ENABLE_SEAFILE_AI', ''):
-    ENABLE_SEAFILE_AI = os.environ.get('ENABLE_SEAFILE_AI', '').lower() == 'true'
+if os.environ.get('ENABLE_SEAFILE_AI'):
+    ENABLE_SEAFILE_AI = os.environ.get('ENABLE_SEAFILE_AI', 'false').lower() == 'true'
 SEAFILE_AI_SECRET_KEY = os.environ.get('SEAFILE_AI_SECRET_KEY', '') or SEAFILE_AI_SECRET_KEY
 SEAFILE_AI_SERVER_URL = os.environ.get('SEAFILE_AI_SERVER_URL', '') or SEAFILE_AI_SERVER_URL
 
 
 SEAFEVENTS_SERVER_URL = 'http://127.0.0.1:8889'
 
-IS_PRO_VERSION = os.environ.get('IS_PRO_VERSION', 'false') == 'true'
+IS_PRO_VERSION = os.environ.get('IS_PRO_VERSION', 'false').lower() == 'true'
 
 CONSTANCE_ENABLED = ENABLE_SETTINGS_VIA_WEB
 CONSTANCE_CONFIG = {
