@@ -57,7 +57,7 @@ from seahub.utils import render_error, is_org_context, \
     normalize_cache_key, gen_file_get_url_by_sharelink, gen_file_get_url_new
 from seahub.utils.ip import get_remote_ip
 from seahub.utils.file_types import (IMAGE, PDF, SVG, AUDIO,
-                                     MARKDOWN, TEXT, VIDEO, SEADOC, TLDRAW, EXCALIDRAW)
+                                     MARKDOWN, TEXT, VIDEO, SEADOC, TLDRAW, EXCALIDRAW, EXCALIDRAW)
 from seahub.utils.timeutils import timestamp_to_isoformat_timestr
 from seahub.utils.star import is_file_starred
 from seahub.utils.file_op import check_file_lock, \
@@ -69,7 +69,7 @@ from seahub.utils.repo import is_repo_owner, parse_repo_perm, is_repo_admin
 from seahub.group.utils import is_group_member
 from seahub.seadoc.utils import get_seadoc_file_uuid, \
         gen_seadoc_access_token, is_seadoc_revision, gen_share_seadoc_access_token
-from seahub.exdraw.utils import get_exdraw_file_uuid
+from seahub.exdraw.utils import get_exdraw_file_uuid, gen_exdraw_access_token, gen_share_exdraw_access_token
 from seahub.seadoc.models import SeadocRevision
 
 import seahub.settings as settings
@@ -386,6 +386,10 @@ def can_preview_file(file_name, file_size, repo):
         error_msg = "File preview unsupported"
         return False, error_msg
 
+    elif filetype in (EXCALIDRAW) and not ENABLE_SEADOC:
+        error_msg = "File preview unsupported"
+        return False, error_msg
+
     elif fileext in OFFICE_WEB_APP_FILE_EXTENSION or \
             fileext in ONLYOFFICE_FILE_EXTENSION:
 
@@ -435,6 +439,9 @@ def can_edit_file(file_name, file_size, repo):
     if file_type in (SEADOC) and ENABLE_SEADOC:
         return True, ''
 
+    if file_type in (EXCALIDRAW) and ENABLE_SEADOC:
+        return True, ''
+
     if ENABLE_OFFICE_WEB_APP_EDIT and \
             file_ext in OFFICE_WEB_APP_EDIT_FILE_EXTENSION:
         return True, ''
@@ -475,7 +482,10 @@ def view_lib_file_via_smart_link(request, dirent_uuid, dirent_name):
         fileext = 'exdraw'
         filetype = 'Excalidraw'
         file_id = seafile_api.get_file_id_by_path(repo_id, req_path)
+        file_uuid = get_exdraw_file_uuid(repo, req_path)
         username = request.user.username
+        exdraw_perm = 'r'
+        excalidraw_access_token = gen_exdraw_access_token(file_uuid, filename, username, permission=exdraw_perm)
         use_onetime = False if filetype in (VIDEO, AUDIO) else True
         token = seafile_api.get_fileserver_access_token(repo_id, file_id,
                                                     'view', username,
@@ -499,6 +509,9 @@ def view_lib_file_via_smart_link(request, dirent_uuid, dirent_name):
             'file_encoding_list': [],
             'filetype': filetype,
             'traffic_over_limit': False,
+            'file_uuid': file_uuid,
+            'excalidraw_server_url': EXCALIDRAW_SERVER_URL,
+            'excalidraw_access_token': excalidraw_access_token,
         }
         return render(request, template, data)
 
@@ -1298,10 +1311,17 @@ def view_shared_file(request, fileshare):
     fileshare.view_cnt = F('view_cnt') + 1
     fileshare.save()
 
+    filename = os.path.basename(path)
+    filetype, fileext = get_file_type_and_ext(filename)
+
     if not request.user.is_authenticated:
         username = ANONYMOUS_EMAIL
+        if filetype == EXCALIDRAW:
+            username = str(time.time())
+        name = ANONYMOUS_EMAIL
     else:
         username = request.user.username
+        name = request.user.name
 
     # check file lock info
     try:
@@ -1316,8 +1336,6 @@ def view_shared_file(request, fileshare):
     can_copy_content = fileshare.get_permissions()['can_copy_content']
     can_download = fileshare.get_permissions()['can_download']
     can_edit = fileshare.get_permissions()['can_edit'] and (not is_locked or locked_by_online_office)
-    filename = os.path.basename(path)
-    filetype, fileext = get_file_type_and_ext(filename)
 
     # download shared file
     if request.GET.get('dl', '') == '1':
@@ -1383,6 +1401,24 @@ def view_shared_file(request, fileshare):
             'seadoc_access_token': ret_dict['seadoc_access_token'],
         }
 
+    if filetype == EXCALIDRAW:
+        file_uuid = get_exdraw_file_uuid(repo, path)
+        ret_dict['file_uuid'] = file_uuid
+        ret_dict['assets_url'] = '/api/v2.1/exdraw/download-image/' + file_uuid
+        ret_dict['excalidraw_server_url'] = EXCALIDRAW_SERVER_URL
+        ret_dict['can_edit_file'] = can_edit
+        exdraw_perm = 'rw' if can_edit else 'r'
+        ret_dict['file_perm'] = exdraw_perm
+
+        if not can_edit:
+            ret_dict['excalidraw_access_token'] = gen_exdraw_access_token(file_uuid, filename, username, permission=exdraw_perm)
+        else:
+            ret_dict['excalidraw_access_token'] = gen_share_exdraw_access_token(file_uuid, filename, username, name, permission=exdraw_perm)
+
+        ret_dict['name'] = name
+        ret_dict['share_link_username'] = username
+        send_file_access_msg(request, repo, path, 'web')
+
     if ENABLE_OFFICE_WEB_APP and fileext in OFFICE_WEB_APP_FILE_EXTENSION or \
             ENABLE_ONLYOFFICE and fileext in ONLYOFFICE_FILE_EXTENSION:
 
@@ -1500,6 +1536,16 @@ def view_shared_file(request, fileshare):
         data['file_perm'] = ret_dict['file_perm']
         data['share_link_username'] = ret_dict['share_link_username']
 
+    if filetype == EXCALIDRAW:
+        data['file_uuid'] = ret_dict['file_uuid']
+        data['assets_url'] = ret_dict['assets_url']
+        data['excalidraw_server_url'] = ret_dict['excalidraw_server_url']
+        data['excalidraw_access_token'] = ret_dict['excalidraw_access_token']
+        data['can_edit_file'] = ret_dict['can_edit_file']
+        data['file_perm'] = ret_dict['file_perm']
+        data['name'] = ret_dict['name']
+        data['share_link_username'] = ret_dict['share_link_username']
+
     if not request.user.is_authenticated:
         from seahub.utils import get_logo_path_by_user
         data['logo_path'] = get_logo_path_by_user(shared_by)
@@ -1986,7 +2032,7 @@ def view_media_file_via_share_link(request):
     shared_file_name = os.path.basename(file_share.path)
     file_type, file_ext = get_file_type_and_ext(shared_file_name)
 
-    if file_type != MARKDOWN:
+    if file_type != MARKDOWN and file_type != EXCALIDRAW:
         err_msg = 'Invalid file type'
         return render_error(request, err_msg)
 
